#!/usr/bin/perl

=begin comment info
 +-----------------------------------------------------------------------------+
 | Copyright 2001, Guardian Digital Inc.
 | $Id: do_step_03.cgi,v 1.3 2003/03/03 14:11:11 rwm Exp $
 |
 | Ryan W. Maple, <ryan@guardiandigital.com>
 +-----------------------------------------------------------------------------+
=end comment info
=cut

  ###  Import our local RPM database and library subroutines and populate %in.
  use RPM::Database '%RPM';
  require "INITCONFIG-lib.pl";
  &ReadParse();


  if ($in{'save'}) {

    ###
    ###  Input Validation  (If iptables is installed and not single_iface).
    ###
    if ($RPM{'iptables'}) {
      if (! $in{'single_iface'}) {
        if ($in{'trusted_iface'} eq "NULL") {
          &PrintError("Please select a Trusted Interface.."); exit;
        }
        elsif ($in{'untrusted_iface'} eq "NULL") {
          &PrintError("Please select an Untrusted Interface."); exit;
        }

        elsif ($in{'trusted_iface'} !~ m/^eth[0-9]+$/) {
          &PrintError("You have selected an invalid Trusted Interface."); exit;
        }
        elsif ($in{'untrusted_iface'} !~ m/^eth[0-9]+$/) {
          &PrintError("You have selected an invalid Untrusted Interface."); exit;
        }

        elsif ($in{'trusted_iface'} eq $in{'untrusted_iface'}) {
          &PrintError("You cannot make the same interface both Trusted and Untrusted."); exit;
        }
      }
    }


    ###
    ###  Activate/Deactivate each service individually.
    ###
    foreach my $s (@SERVICES) {
      my ($func);

      if ($in{"activate_$s->{'init'}"} && ($s->{'init'} ne "xinetd")) {
        $func = "--add";
      }
      else {
        $func = "--del";
      }

      ###  Don't ever touch xinetd.
      if ($s->{'init'} ne "xinetd") {
        system "$CHKCONFIG_BIN $func $s->{'init'} > /dev/null 2>&1"
      }
    }

    ###
    ###  Special case for 'xinetd' (ftp is the only service at the moment).
    ###
    if ($in{'activate_xinetd'}) { &toggleXinetdService("ftp", "on");  }
    else                        { &toggleXinetdService("ftp", "off"); }


    ###
    ###  Firewall "Stuff"  (if iptables is installed).
    ###
    if ($RPM{'iptables'}) {
      ###
      ###  Define local variables.
      ###
      my ($lref);
      my ($TRUSTED_IF, $UNTRUSTED_IF);
      my ($TRUSTED_IP, $UNTRUSTED_IP);
      my ($TRUSTED_NET, $UNTRUSTED_NET);

      ###
      ###  Save the trusted/untrusted interface information.
      ###
      $TRUSTED_IF    =  $in{'trusted_iface'};
      $UNTRUSTED_IF  =  $in{'untrusted_iface'};
      $lref          =  &read_file_lines("/etc/firewall/firewall.conf");

      ###  Get our (un)trusted IPs.
      $TRUSTED_IP = $UNTRUSTED_IP = "";
      foreach my $i (&GetInterfaces()) {
        if ($i->{'iface'} eq $TRUSTED_IF) {
          $TRUSTED_IP     = $i->{'address'};

          $TRUSTED_NET    = &GetNetworkNumber($i->{'address'}, $i->{'netmask'});
          $TRUSTED_NET   .= "/$i->{'netmask'}";
        }
        elsif ($i->{'iface'} eq $UNTRUSTED_IF) {
          $UNTRUSTED_IP   = $i->{'address'};

          $UNTRUSTED_NET  = &GetNetworkNumber($i->{'address'}, $i->{'netmask'});
          $UNTRUSTED_NET .= "/$i->{'netmask'}";
        }
      }

      ###  Zero-out the "trusted" stuff if we only have one interface.
      if ($in{'single_iface'}) {
        $TRUSTED_IF = ""; $TRUSTED_IP = ""; $TRUSTED_NET = "";
      }

      ###  Update the file.
      for (my $i = 0; $i < @$lref; $i++) {
        if (@$lref[$i] =~ m/^TRUSTED_IF=.*$/) {
          @$lref[$i] = "TRUSTED_IF=$TRUSTED_IF";
        }
        elsif (@$lref[$i] =~ m/^UNTRUSTED_IF=.*$/) {
          @$lref[$i] = "UNTRUSTED_IF=$UNTRUSTED_IF";
        }

        elsif (@$lref[$i] =~ m/^TRUSTED_IP=.*$/) {
          @$lref[$i] = "TRUSTED_IP=$TRUSTED_IP";
        }
        elsif (@$lref[$i] =~ m/^UNTRUSTED_IP=.*$/) {
          @$lref[$i] = "UNTRUSTED_IP=$UNTRUSTED_IP";
        }

        elsif (@$lref[$i] =~ m/^TRUSTED_NET=.*$/) {
          @$lref[$i] = "TRUSTED_NET=$TRUSTED_NET";
        }
        elsif (@$lref[$i] =~ m/^UNTRUSTED_NET=.*$/) {
          @$lref[$i] = "UNTRUSTED_NET=$UNTRUSTED_NET";
        }
      }

      ###  Write the file back to disk.
      &flush_file_lines();
    }

    # Fix /etc/logsum.conf.
    my $lref = &read_file_lines('/etc/logsum.conf');
    for (my $i = 0; $i < @$lref; $i++) {
      if (@$lref[$i] =~ m/^EMAIL/) {
        @$lref[$i] = "EMAIL = $in{'admin_email'}";
      }
    }
    &flush_file_lines();

    # Fix /etc/postfix/aliases.
    my $lref = &read_file_lines('/etc/postfix/aliases');
    for (my $i = 0; $i < @$lref; $i++) {
      if (@$lref[$i] =~ m/^root\:/) {
        @$lref[$i] = "root:\t\t$in{'admin_email'}";
      }
    }
    &flush_file_lines();
  }


  &redirect("summary.cgi");
